==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ToolActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionButtonDescription } from "./ToolActionButtonDescription";
/**
 * @hidden
 */
var ToolActionButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionButtonDescriptionMetadata, _super);
    function ToolActionButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionButtonDescriptionMetadata.b = function (a) {
        if (ToolActionButtonDescriptionMetadata.a == null) {
            ToolActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionButtonDescriptionMetadata.c(ToolActionButtonDescriptionMetadata.a);
        }
        if (a.k(ToolActionButtonDescriptionMetadata.a)) {
            return;
        }
        a.aa(ToolActionButtonDescriptionMetadata.a);
    };
    ToolActionButtonDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
    };
    ToolActionButtonDescriptionMetadata.d = function (a) {
        ToolActionButtonDescriptionMetadata.b(a);
        a.ac("ToolActionButton", function () { return new ToolActionButtonDescription(); });
        a.ab("ToolActionButton", ToolActionButtonDescriptionMetadata.a);
    };
    ToolActionButtonDescriptionMetadata.$t = markType(ToolActionButtonDescriptionMetadata, 'ToolActionButtonDescriptionMetadata');
    ToolActionButtonDescriptionMetadata.a = null;
    return ToolActionButtonDescriptionMetadata;
}(Base));
export { ToolActionButtonDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/ToolActionButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionButtonDescription } from "./ToolActionButtonDescription";
/**
 * @hidden
 */
var ToolActionButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionButtonDescriptionMetadata, _super);
    function ToolActionButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionButtonDescriptionMetadata.b = function (a) {
        if (ToolActionButtonDescriptionMetadata.a == null) {
            ToolActionButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionButtonDescriptionMetadata.c(ToolActionButtonDescriptionMetadata.a);
        }
        if (a.k(ToolActionButtonDescriptionMetadata.a)) {
            return;
        }
        a.ac(ToolActionButtonDescriptionMetadata.a);
    };
    ToolActionButtonDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
        a.item("DisplayType", "ExportedType:string:ToolActionButtonDisplayType");
        a.item("DisplayType@names", "Raised;Flat;Outlined");
        a.item("CornerRadius", "Number:double");
    };
    ToolActionButtonDescriptionMetadata.d = function (a) {
        ToolActionButtonDescriptionMetadata.b(a);
        a.ae("ToolActionButton", function () { return new ToolActionButtonDescription(); });
        a.ad("ToolActionButton", ToolActionButtonDescriptionMetadata.a);
    };
    ToolActionButtonDescriptionMetadata.$t = markType(ToolActionButtonDescriptionMetadata, 'ToolActionButtonDescriptionMetadata');
    ToolActionButtonDescriptionMetadata.a = null;
    return ToolActionButtonDescriptionMetadata;
}(Base));
export { ToolActionButtonDescriptionMetadata };
